Flags indicating checksum, segmentation and other offload work to be done, or already done, by hardware or lower layers. It is split into separate inbound and outbound flags.

Outbound flags that are set by upper protocol layers requesting lower layers, or ideally the hardware, to perform these offloading tasks. For outbound packets this field and its flags can be directly tested against ifnet if_hwassist. Note that the outbound and the inbound flags do not collide right now but they could be allowed to (as long as the flags are scrubbed appropriately when the direction of an mbuf changes). CSUM_BITS would also have to split into CSUM_BITS_TX and CSUM_BITS_RX.

CSUM_INNER_ is the same as CSUM_ but it applies to the inner frame. The CSUM_ENCAP_ bits identify the outer encapsulation.

Constants

contains merged segments

Only v4, no v6 IP hdr csum

VXLAN outer encapsulation

IP header checksum offload

iSCSI checksum offload

SCTP checksum offload

TCP checksum offload

TCP segmentation offload

UDP checksum offload

iSCSI checksum offload

SCTP checksum offload

TCP checksum offload

TCP segmentation offload

UDP checksum offload

calculated layer 3 csum

checksum is correct

calculated layer 4 csum

checksum is correct

calculated layer 5 csum

checksum is correct

Packet header has send tag